from setuptools import setup, find_packages

setup(
    name='xursparks',
    version='1.2.6',
    packages=find_packages(),
    python_requires=">=3.10",
    install_requires=[
        'requests',
        'numpy==1.26.4',
        'pandas',
        'pyspark==3.5.2',
        'boto3',
        'openpyxl',
        'xurpas_data_quality',
        'openai==1.54.5',
        'langchain==0.2.17',
        'langchain_community==0.2.19',
        'langchain_core==0.2.43',
        'langchain_openai==0.1.20',
        'llama_index==0.10.39',
        'llama_index.core==0.10.68.post1',
        'langchain_experimental==0.0.65',
        'tabulate==0.9.0',
        'PyMuPDF==1.24.14',
        'llama-index-llms-langchain==0.3.0',
        'PyHive==0.7.0',
        'thrift>=0.12.0',
        'thrift-sasl>=0.4.3',
        'sasl>=0.3.1',
        'cryptography==45.0.4',
        'requests_ntlm>=1.3.0'
    ],
    author='Randell Gabriel Santos',
    author_email='randellsantos@gmail.com',
    description='Encapsulating Apache Spark for Easy Usage',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/dev-doods687/xursparks',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
